==> option-annotations-2.7.0-sources.jar: io/dekorate/option/adapter/VcsConfigAdapter.java <==
package io.dekorate.option.adapter;

import io.dekorate.option.annotation.VcsOptions;
import io.dekorate.project.Project;
import io.dekorate.project.BuildInfo;
import io.dekorate.option.config.VcsConfig;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import io.dekorate.project.ScmInfo;
import java.lang.Boolean;
import java.util.Map;
import io.dekorate.option.config.VcsConfigBuilder;

 /**
  * Generated
  */
public class VcsConfigAdapter{
  public static io.dekorate.option.config.VcsConfig adapt(io.dekorate.option.annotation.VcsOptions instance) {
    return newBuilder(instance).build();
  }
  public static io.dekorate.option.config.VcsConfigBuilder newBuilder(io.dekorate.option.annotation.VcsOptions instance) {
    return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(null,
            null,
            instance.remote(),
            instance.httpsPreferred()));
  }
  public static io.dekorate.option.config.VcsConfig adapt(java.util.Map map) {
    return new io.dekorate.option.config.VcsConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null));
  }
  public static io.dekorate.option.config.VcsConfigBuilder newBuilder(java.util.Map map) {
    return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null)));
  }
  public static java.lang.String[] toStringArray(java.lang.Object o) {
            if (o instanceof String[]) {
          return (String[]) o;
        }
        if (o instanceof String) {
          String s =  (String) o;
          return s.split(",[ ]*");
        }
        else if (o instanceof List) {
          List c = (List) o;
          String[] result = new String[c.size()]; 
          for (int i=0; i <= c.size(); i++) {
            result[i] = String.valueOf(c.get(i));
          }
          return result;
        }
        return new String[0];
    

  }
  
}

==> option-annotations-2.10.0-sources.jar: io/dekorate/option/adapter/VcsConfigAdapter.java <==
package io.dekorate.option.adapter;

import io.dekorate.option.annotation.VcsOptions;
import io.dekorate.project.Project;
import io.dekorate.project.BuildInfo;
import io.dekorate.option.config.VcsConfig;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import io.dekorate.project.ScmInfo;
import java.lang.Boolean;
import java.util.Map;
import io.dekorate.option.config.VcsConfigBuilder;

 /**
  * Generated
  */
public class VcsConfigAdapter{
  public static VcsConfig adapt(VcsOptions instance) {
    return newBuilder(instance).build();
  }
  public static VcsConfigBuilder newBuilder(io.dekorate.option.annotation.VcsOptions instance) {
    return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(null,
            null,
            instance.remote(),
            instance.httpsPreferred()));
  }
  public static io.dekorate.option.config.VcsConfig adapt(Map map) {
    return new io.dekorate.option.config.VcsConfig(
null,
null,
               (String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
               (Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null));
  }
  public static io.dekorate.option.config.VcsConfigBuilder newBuilder(java.util.Map map) {
    return new VcsConfigBuilder(new io.dekorate.option.config.VcsConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("remote", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("httpsPreferred", null) : null)));
  }
  public static java.lang.String[] toStringArray(Object o) {
            if (o instanceof String[]) {
          return (String[]) o;
        }
        if (o instanceof String) {
          String s =  (String) o;
          return s.split(",[ ]*");
        }
        else if (o instanceof List) {
          List c = (List) o;
          String[] result = new String[c.size()]; 
          for (int i=0; i <= c.size(); i++) {
            result[i] = String.valueOf(c.get(i));
          }
          return result;
        }
        return new String[0];
    

  }
  
}
